@@ -3,13 +3,18 @@ use utf8;
 use strict;
 use warnings FATAL => 'all';
 
-use Muldis::Rosetta::Interface;
+use Muldis::Rosetta::Interface 0.011000;
+
+#use Muldis::Rosetta::Engine::Example::Runtime;
+#use Muldis::Rosetta::Engine::Example::Value;
+#use Muldis::Rosetta::Engine::Example::PlainText;
+#use Muldis::Rosetta::Engine::Example::HostedData;
 
 ###########################################################################
 ###########################################################################
 
 { package Muldis::Rosetta::Engine::Example; # module
-    use version; our $VERSION = qv('0.10.0');
+    use version 0.74; our $VERSION = qv('0.11.0');
     # Note: This given version applies to all of this file's packages.
 
 ###########################################################################
@@ -33,40 +38,24 @@ sub new_machine {
 
     with 'Muldis::Rosetta::Interface::Machine';
 
-    use Carp;
-
-    # User-supplied config data for this Machine object.
-    # For the moment, the Example Engine doesn't actually have anything
-    # that can be config in this way, so input $machine_config is ignored.
-    has '_machine_config' => (
-        is       => 'rw',
-        init_arg => 'machine_config',
-        required => 0,
-        default  => undef,
-    );
-
-    # Lists of user-held objects associated with parts of this Machine.
-    # For each of these, Hash keys are obj .WHERE/addrs, vals the objs.
-    # These should be weak obj-refs, so objs disappear from here
-    has '_assoc_processes' => (
+    has '_inner' => (
         is      => 'rw',
-        default => sub { {} },
+        isa     => 'Muldis::Rosetta::Engine::Example::Runtime::Machine',
+        default => undef,
     );
 
 ###########################################################################
 
 sub BUILD {
-    my ($self) = @_;
+    my ($self, $args) = @_;
+    my ($machine_config) = @{$args}{'machine_config'};
 
-    # TODO: input checks on $!machine_config.
+    # TODO: input checks on $machine_config.
+    defined $machine_config or $machine_config = {};
 
-    return;
-}
+#    $self->_inner( Muldis::Rosetta::Engine::Example::Runtime::Machine
+#        ->new({ 'machine_config' => $machine_config }) );
 
-sub DEMOLISH {
-    my ($self) = @_;
-    # TODO: check for active trans and rollback ... or member VM does it.
-    # Likewise with closing open files or whatever.
     return;
 }
 
@@ -79,11 +68,6 @@ sub new_process {
         'assoc_machine' => $self, 'process_config' => $process_config });
 }
 
-sub assoc_processes {
-    my ($self) = @_;
-    return [values %{$self->_assoc_processes}];
-}
-
 ###########################################################################
 
     __PACKAGE__->meta()->make_immutable();
@@ -97,69 +81,56 @@ sub assoc_processes {
 
     with 'Muldis::Rosetta::Interface::Process';
 
-    use Carp;
-    use Scalar::Util qw( refaddr weaken );
-
     has '_assoc_machine' => (
-        is       => 'rw',
+        is       => 'ro',
+        isa      => 'Muldis::Rosetta::Engine::Example::Public::Machine',
         init_arg => 'assoc_machine',
         required => 1,
-        isa      => 'Muldis::Rosetta::Engine::Example::Public::Machine',
     );
 
-    # User-supplied config data for this Process object.
-    # For the moment, the Example Engine doesn't actually have anything
-    # that can be config in this way, so input $process_config is ignored.
-    has '_process_config' => (
+    has '_inner' => (
         is      => 'rw',
-        init_arg => 'process_config',
-        required => 0,
-        default  => undef,
+        isa     => 'Muldis::Rosetta::Engine::Example::Runtime::Process',
+        default => undef,
+# Disabled since Moose::Role's "requires" doesn't recog auto-gen methods.
+#        handles => [qw(
+#            trans_nest_level start_trans commit_trans rollback_trans
+#        )],
     );
 
-    has '_command_lang' => (
+    has '_pt_command_lang' => (
         is      => 'rw',
+        isa     => 'Maybe[Str]',
         default => undef,
     );
-
-    # Lists of user-held objects associated with parts of this Process.
-    # For each of these, Hash keys are obj .WHERE/addrs, vals the objs.
-    # These should be weak obj-refs, so objs disappear from here
-    has '_assoc_values' => (
+    has '_hd_command_lang' => (
         is      => 'rw',
-        default => sub { {} },
-    );
-
-    # Maintain actual state of the this DBMS' virtual machine.
-    # TODO: the VM itself should be in another file, this attr with it.
-    has '_trans_nest_level' => (
-        is      => 'rw',
-        default => 0,
+        isa     => 'Maybe[ArrayRef]',
+        default => undef,
     );
 
 ###########################################################################
 
 sub BUILD {
-    my ($self) = @_;
+    my ($self, $args) = @_;
+    my ($process_config) = @{$args}{'process_config'};
 
-    $self->_assoc_machine->_assoc_processes->{refaddr $self} = $self;
-    weaken $self->_assoc_machine->_assoc_processes->{refaddr $self};
+    # TODO: input checks on $process_config.
+    defined $process_config or $process_config = {};
 
-    # TODO: input checks on $!process_config.
+#    $self->_inner( Muldis::Rosetta::Engine::Example::Runtime::Process
+#            ->new({
+#        'assoc_machine'  => $self->_assoc_machine->_inner,
+#        'process_config' => $process_config
+#    }) );
 
     return;
 }
 
-sub DEMOLISH {
-    my ($self) = @_;
-    # TODO: check for active trans and rollback ... or member VM does it.
-    # Likewise with closing open files or whatever.
-    delete $self->_assoc_machine->_assoc_processes->{refaddr $self};
-    return;
-}
-
 ###########################################################################
 
+# Needed since Moose::Role's "requires" doesn't recognize auto-gen methods.
+
 sub assoc_machine {
     my ($self) = @_;
     return $self->_assoc_machine;
@@ -167,15 +138,27 @@ sub assoc_machine {
 
 ###########################################################################
 
-sub command_lang {
+sub pt_command_lang {
     my ($self) = @_;
-    return $self->_command_lang;
+    return $self->_pt_command_lang;
 }
 
-sub update_command_lang {
+sub update_pt_command_lang {
     my ($self, $args) = @_;
     my ($lang) = @{$args}{'lang'};
-    $self->_command_lang( $lang );
+    $self->_pt_command_lang( $lang );
+    return;
+}
+
+sub hd_command_lang {
+    my ($self) = @_;
+    return $self->_hd_command_lang;
+}
+
+sub update_hd_command_lang {
+    my ($self, $args) = @_;
+    my ($lang) = @{$args}{'lang'};
+    $self->_hd_command_lang( $lang );
     return;
 }
 
@@ -199,18 +182,13 @@ sub new_value {
         'assoc_process' => $self, 'source_code' => $source_code });
 }
 
-sub assoc_values {
-    my ($self) = @_;
-    return [values %{$self->_assoc_values}];
-}
-
 ###########################################################################
 
 sub func_invo {
     my ($self, $args) = @_;
     my ($function, $f_args) = @{$args}{'function', 'args'};
 
-    my $result = $self->new_value(); # TODO, the real work
+    my $result = $self->new_value({ 'source_code' => 1 }); # TODO real work
 
     return $result;
 }
@@ -237,35 +215,28 @@ sub proc_invo {
 
 ###########################################################################
 
+# Needed since Moose::Role's "requires" doesn't recognize auto-gen methods.
+
 sub trans_nest_level {
     my ($self) = @_;
-    return $self->_trans_nest_level;
+    return $self->_inner->trans_nest_level;
 }
 
 sub start_trans {
     my ($self) = @_;
-    # TODO: the actual work.
-    $self->_trans_nest_level( $self->_trans_nest_level ++ );
+    $self->_inner->start_trans();
     return;
 }
 
 sub commit_trans {
     my ($self) = @_;
-    confess q{commit_trans(): Could not commit a transaction;}
-            . q{ none are currently active.}
-        if $self->_trans_nest_level == 0;
-    # TODO: the actual work.
-    $self->_trans_nest_level( $self->_trans_nest_level -- );
+    $self->_inner->commit_trans();
     return;
 }
 
 sub rollback_trans {
     my ($self) = @_;
-    confess q{rollback_trans(): Could not rollback a transaction;}
-            . q{ none are currently active.}
-        if $self->_trans_nest_level == 0;
-    # TODO: the actual work.
-    $self->_trans_nest_level( $self->_trans_nest_level -- );
+    $self->_inner->rollback_trans();
     return;
 }
 
@@ -282,19 +253,18 @@ sub rollback_trans {
 
     with 'Muldis::Rosetta::Interface::Value';
 
-    use Scalar::Util qw( refaddr weaken );
-
     has '_assoc_process' => (
-        is       => 'rw',
+        is       => 'ro',
+        isa      => 'Muldis::Rosetta::Engine::Example::Public::Process',
         init_arg => 'assoc_process',
         required => 1,
-        isa      => 'Muldis::Rosetta::Engine::Example::Public::Process',
     );
 
-    has '_value' => (
-        is => 'rw',
+    has '_inner' => (
+        is      => 'rw',
+        does    => 'Muldis::Rosetta::Engine::Example::Value::Universal',
+        default => undef,
     );
-    # TODO: cache Perl-Hosted Muldis D version of $!value.
 
 ###########################################################################
 
@@ -302,24 +272,36 @@ sub BUILD {
     my ($self, $args) = @_;
     my ($source_code) = @{$args}{'source_code'};
 
-    $self->_assoc_process->_assoc_values->{refaddr $self} = $self;
-    weaken $self->_assoc_process->_assoc_values->{refaddr $self};
+    confess q{new_value(): Bad :$source_code arg; it is undefined.}
+        if !defined $source_code;
 
-    # TODO: input checks on $source_code.
-#    $self->_value = Muldis::Rosetta::Engine::Example::VM::Value->new({
-#        'source_code' => $source_code }); # TODO; or some such
+    my $assoc_process = $self->_assoc_process;
 
-    return;
-}
+    if (ref $source_code) {
+#        $self->_inner( Muldis::Rosetta::Engine::Example::HostedData
+#                ->value_from_source_code({
+#            'assoc_process' => $assoc_process->_inner,
+#            'source_code' => $source_code,
+#            'exp_command_lang' => $assoc_process->_hd_command_lang,
+#        }) );
+    }
+
+    else {
+#        $self->_inner( Muldis::Rosetta::Engine::Example::PlainText
+#                ->value_from_source_code({
+#            'assoc_process' => $assoc_process->_inner,
+#            'source_code' => $source_code,
+#            'exp_command_lang' => $assoc_process->_pt_command_lang,
+#        }) );
+    }
 
-sub DEMOLISH {
-    my ($self) = @_;
-    delete $self->_assoc_process->_assoc_values->{refaddr $self};
     return;
 }
 
 ###########################################################################
 
+# Needed since Moose::Role's "requires" doesn't recognize auto-gen methods.
+
 sub assoc_process {
     my ($self) = @_;
     return $self->_assoc_process;
@@ -327,10 +309,27 @@ sub assoc_process {
 
 ###########################################################################
 
-sub source_code {
+sub pt_source_code {
     my ($self, $args) = @_;
     my ($lang) = @{$args}{'lang'};
-#    return $self->_value->source_code( $lang ); # TODO; or some such
+#    return Muldis::Rosetta::Engine::Example::PlainText
+#            ->source_code_from_value({
+#        'value' => $self->_inner,
+#        'exp_command_lang'
+#            => ($self->_assoc_process->_pt_command_lang || $lang),
+#    });
+    return;
+}
+
+sub hd_source_code {
+    my ($self, $args) = @_;
+    my ($lang) = @{$args}{'lang'};
+#    return Muldis::Rosetta::Engine::Example::HostedData
+#            ->source_code_from_value({
+#        'value' => $self->_inner,
+#        'exp_command_lang'
+#            => ($self->_assoc_process->_hd_command_lang || $lang),
+#    });
     return;
 }
 
@@ -356,7 +355,7 @@ Self-contained reference implementation of a Muldis Rosetta Engine
 
 =head1 VERSION
 
-This document describes Muldis::Rosetta::Engine::Example version 0.10.0 for
+This document describes Muldis::Rosetta::Engine::Example version 0.11.0 for
 Perl 5.
 
 It also describes the same-number versions for Perl 5 of
@@ -405,8 +404,8 @@ Example written in any of the following:
 See L<Muldis::D::Dialect::PTMD_Tiny> for details.
 
 The language name is specified either as a Perl character string whose
-value is C<Muldis_D:'http://muldis.com':'0.46.0':'PTMD_Tiny':{}> or as a
-Perl array whose value is C<[ 'Muldis_D', 'http://muldis.com', '0.46.0',
+value is C<Muldis_D:'http://muldis.com':'0.47.0':'PTMD_Tiny':{}> or as a
+Perl array whose value is C<[ 'Muldis_D', 'http://muldis.com', '0.47.0',
 'PTMD_Tiny', {} ]>.  No other version numbers are currently supported.
 
 =item B<Tiny Perl Hosted Data Muldis D>
@@ -414,8 +413,8 @@ Perl array whose value is C<[ 'Muldis_D', 'http://muldis.com', '0.46.0',
 See L<Muldis::D::Dialect::HDMD_Perl_Tiny> for details.
 
 The language name is specified either as a Perl character string whose
-value is C<Muldis_D:'http://muldis.com':'0.46.0':'HDMD_Perl_Tiny':{}> or as
-a Perl array whose value is C<[ 'Muldis_D', 'http://muldis.com', '0.46.0',
+value is C<Muldis_D:'http://muldis.com':'0.47.0':'HDMD_Perl_Tiny':{}> or as
+a Perl array whose value is C<[ 'Muldis_D', 'http://muldis.com', '0.47.0',
 'HDMD_Perl_Tiny', {} ]>.  No other version numbers are currently supported.
 
 =back
@@ -443,7 +442,7 @@ It also requires these Perl 5 packages that are on CPAN:
 L<Moose-0.55|Moose>.
 
 It also requires these Perl 5 classes that are in the current distribution:
-L<Muldis::Rosetta::Interface-0.10.0|Muldis::Rosetta::Interface>.
+L<Muldis::Rosetta::Interface-0.11.0|Muldis::Rosetta::Interface>.
 
 =head1 INCOMPATIBILITIES
 
